# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

######################### We start with some black magic to print on failure.

# Change 1..1 below to 1..last_test_to_print .
# (It may become useful if the test is moved to ./t subdirectory.)


use strict;
use warnings;

use Test::More tests => 3;

use File::Spec::Functions qw( catfile );

BEGIN { use_ok( 'SAOsac::gi' ) }

######################### End of black magic.

# Insert your test code below (better if it prints "ok 13"
# (correspondingly "not ok 13") depending on the success of chunk 13
# of the test code):

my $have_ndiff = whence('ndiff');

my @test_inputs = <data/*.gi>;
SKIP: {
    skip ( "ndiff not available; cannot perform tests", scalar @test_inputs  )
      unless $have_ndiff;

    ok( cmpgi( $_ ), "cmp $_" ) foreach @test_inputs;
};


sub cmpgi
{
  my ( $gi ) = @_;

  our ( $system, $paraboloid, $hyperboloid );
  do "$gi.in";

  open( GI, $gi ) or die( "couldn't open $gi\n" );
  my $comment = <GI>;
  close( GI );
  chomp $comment;

  SAOsac::gi::create( "$gi.cmp", $comment, 
		      $system, $paraboloid, $hyperboloid );

  my $ok = system( "ndiff -separator '[ ,]+' $gi $gi.cmp" ) == 0;
  unlink "$gi.cmp";
  return $ok
}


# ick. cheap imitation of Env::Path::Whence, just so there's no
# dependence on Env::Path.
sub whence
{
    my ( $exe ) = @_;

    foreach my $path ( split(':', $ENV{PATH} ) )
    {
	return 1 if -x catfile( $path, $exe );
    }

    return 0;
}
